#include "mainwindow.h"
#include "ui_mainwindow.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    QObject::connect(ui->actionOpen, SIGNAL(triggered()),this,SLOT(openFileSlot()));
    QObject::connect(ui->actionSettings, SIGNAL(triggered()),this,SLOT(displaySettings()));
    QCoreApplication::setOrganizationName("Sebastian Bota");
    QCoreApplication::setOrganizationDomain("");
    QCoreApplication::setApplicationName("QTail");

    restoreGeometry(settings.value("mainWindowGeometry").toByteArray());

}

MainWindow::~MainWindow()
{
    delete ui;
}


void MainWindow::openFileSlot()
{
    QString file = QFileDialog::getOpenFileName(this,"Select file to monitor");
    if(!file.isNull())
    {
        int lines = settings.value("lines",10).toInt();

        ui->textEdit->setText(getLastLines(file,lines));
        ui->statusBar->showMessage(file);

        QFileSystemWatcher *systemWatcher = new QFileSystemWatcher(this);
        systemWatcher->addPath(file);

        QObject::connect(systemWatcher,SIGNAL(fileChanged(QString)),this,SLOT(fileChanged(QString)));
    }
}

void MainWindow::displaySettings()
{
    SettingsDialog* dialog = new SettingsDialog();


    if( dialog->exec() == SettingsDialog::Accepted)
    {
        settings.setValue("lines",dialog->getLines());
    }

}


QString MainWindow::getLastLines(QString file, int lines)
{
    QFile fileObject(file);
    fileObject.open(QIODevice::ReadOnly);

    fileObject.seek(fileObject.size()-1);

    int count = 0;

    while ( (count <=lines) && (fileObject.pos() > 0) )
    {
        char ch;
        fileObject.getChar(&ch);
        fileObject.seek(fileObject.pos()-2);

        if (ch == '\n')
        {
            count++;
        }
     }

    QString r = fileObject.readAll();
    fileObject.close();

    return r;
}

void MainWindow::fileChanged(QString file)
{
    ui->textEdit->setText(getLastLines(file,10));
}
